# Mara App

[![Build Status](https://travis-ci.org/mara/mara-app.svg?branch=master)](https://travis-ci.org/mara/mara-app)
![PyPI - License](https://img.shields.io/pypi/l/mara-app.svg)
[![PyPI version](https://badge.fury.io/py/mara-app.svg)](https://badge.fury.io/py/mara-app)
[![Slack Status](https://img.shields.io/badge/slack-join_chat-white.svg?logo=slack&style=social)](https://communityinviter.com/apps/mara-users/public-invite)


A flask app for building backends that are distributed across separate packages. Provides 
- a Bootstrap 4 based page layout 
- auto-detection of flask blueprints
- auto-detection of navigation entries
- auto-detection of click command line interfaces

Please have a look at the [mara example application](https://github.com/mara/mara-example-project) for an example of how to use this.
